<?php
/**
 * This file loads all the options related to Theme Options settings page.
 * 
 * @package Counsel
 * @subpackage Core-Options
 * @category Options
 * @since Counsel 1.0 
 */

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function mudthemes_optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
        
	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function mudthemes_optionsframework_options() {

        $icons = array('glass', 'music', 'search', 'envelope-o', 'heart', 'star', 'star-o', 'user', 'film', 'th-large', 'th', 'th-list', 'check', 'times', 'search-plus', 'search-minus', 'power-off', 'signal', 'gear', 'cog', 'trash-o', 'home', 'file-o', 'clock-o', 'road', 'download', 'arrow-circle-o-down', 'arrow-circle-o-up', 'inbox', 'play-circle-o', 'rotate-right', 'repeat', 'refresh', 'list-alt', 'lock', 'flag', 'headphones', 'volume-off', 'volume-down', 'volume-up', 'qrcode', 'barcode', 'tag', 'tags', 'book', 'bookmark', 'print', 'camera', 'font', 'bold', 'italic', 'text-height', 'text-width', 'align-left', 'align-center', 'align-right', 'align-justify', 'list', 'dedent', 'outdent', 'indent', 'video-camera', 'photo', 'image', 'picture-o', 'pencil', 'map-marker', 'adjust', 'tint', 'edit', 'pencil-square-o', 'share-square-o', 'check-square-o', 'arrows', 'step-backward', 'fast-backward', 'backward', 'play', 'pause', 'stop', 'forward', 'fast-forward', 'step-forward', 'eject', 'chevron-left', 'chevron-right', 'plus-circle', 'minus-circle', 'times-circle', 'check-circle', 'question-circle', 'info-circle', 'crosshairs', 'times-circle-o', 'check-circle-o', 'ban', 'arrow-left', 'arrow-right', 'arrow-up', 'arrow-down', 'mail-forward', 'share', 'expand', 'compress', 'plus', 'minus', 'asterisk', 'exclamation-circle', 'gift', 'leaf', 'fire', 'eye', 'eye-slash', 'warning', 'exclamation-triangle', 'plane', 'calendar', 'random', 'comment', 'magnet', 'chevron-up', 'chevron-down', 'retweet', 'shopping-cart', 'folder', 'folder-open', 'arrows-v', 'arrows-h', 'bar-chart-o', 'twitter-square', 'facebook-square', 'camera-retro', 'key', 'gears', 'cogs', 'comments', 'thumbs-o-up', 'thumbs-o-down', 'star-half', 'heart-o', 'sign-out', 'linkedin-square', 'thumb-tack', 'external-link', 'sign-in', 'trophy', 'github-square', 'upload', 'lemon-o', 'phone', 'square-o', 'bookmark-o', 'phone-square', 'twitter', 'facebook', 'github', 'unlock', 'credit-card', 'rss', 'hdd-o', 'bullhorn', 'bell', 'certificate', 'hand-o-right', 'hand-o-left', 'hand-o-up', 'hand-o-down', 'arrow-circle-left', 'arrow-circle-right', 'arrow-circle-up', 'arrow-circle-down', 'globe', 'wrench', 'tasks', 'filter', 'briefcase', 'arrows-alt', 'group', 'users', 'chain', 'link', 'cloud', 'flask', 'cut', 'scissors', 'copy', 'files-o', 'paperclip', 'save', 'floppy-o', 'square', 'navicon', 'reorder', 'bars', 'list-ul', 'list-ol', 'strikethrough', 'underline', 'table', 'magic', 'truck', 'pinterest', 'pinterest-square', 'google-plus-square', 'google-plus', 'money', 'caret-down', 'caret-up', 'caret-left', 'caret-right', 'columns', 'unsorted', 'sort', 'sort-down', 'sort-desc', 'sort-up', 'sort-asc', 'envelope', 'linkedin', 'rotate-left', 'undo', 'legal', 'gavel', 'dashboard', 'tachometer', 'comment-o', 'comments-o', 'flash', 'bolt', 'sitemap', 'umbrella', 'paste', 'clipboard', 'lightbulb-o', 'exchange', 'cloud-download', 'cloud-upload', 'user-md', 'stethoscope', 'suitcase', 'bell-o', 'coffee', 'cutlery', 'file-text-o', 'building-o', 'hospital-o', 'ambulance', 'medkit', 'fighter-jet', 'beer', 'h-square', 'plus-square', 'angle-double-left', 'angle-double-right', 'angle-double-up', 'angle-double-down', 'angle-left', 'angle-right', 'angle-up', 'angle-down', 'desktop', 'laptop', 'tablet', 'mobile-phone', 'mobile', 'circle-o', 'quote-left', 'quote-right', 'spinner', 'circle', 'mail-reply', 'reply', 'github-alt', 'folder-o', 'folder-open-o', 'smile-o', 'frown-o', 'meh-o', 'gamepad', 'keyboard-o', 'flag-o', 'flag-checkered', 'terminal', 'code', 'mail-reply-all', 'reply-all', 'star-half-empty', 'star-half-full', 'star-half-o', 'location-arrow', 'crop', 'code-fork', 'unlink', 'chain-broken', 'question', 'info', 'exclamation', 'superscript', 'subscript', 'eraser', 'puzzle-piece', 'microphone', 'microphone-slash', 'shield', 'calendar-o', 'fire-extinguisher', 'rocket', 'maxcdn', 'chevron-circle-left', 'chevron-circle-right', 'chevron-circle-up', 'chevron-circle-down', 'html5', 'css3', 'anchor', 'unlock-alt', 'bullseye', 'ellipsis-h', 'ellipsis-v', 'rss-square', 'play-circle', 'ticket', 'minus-square', 'minus-square-o', 'level-up', 'level-down', 'check-square', 'pencil-square', 'external-link-square', 'share-square', 'compass', 'toggle-down', 'caret-square-o-down', 'toggle-up', 'caret-square-o-up', 'toggle-right', 'caret-square-o-right', 'euro', 'eur', 'gbp', 'dollar', 'usd', 'rupee', 'inr', 'cny', 'rmb', 'yen', 'jpy', 'ruble', 'rouble', 'rub', 'won', 'krw', 'bitcoin', 'btc', 'file', 'file-text', 'sort-alpha-asc', 'sort-alpha-desc', 'sort-amount-asc', 'sort-amount-desc', 'sort-numeric-asc', 'sort-numeric-desc', 'thumbs-up', 'thumbs-down', 'youtube-square', 'youtube', 'xing', 'xing-square', 'youtube-play', 'dropbox', 'stack-overflow', 'instagram', 'flickr', 'adn', 'bitbucket', 'bitbucket-square', 'tumblr', 'tumblr-square', 'long-arrow-down', 'long-arrow-up', 'long-arrow-left', 'long-arrow-right', 'apple', 'windows', 'android', 'linux', 'dribbble', 'skype', 'foursquare', 'trello', 'female', 'male', 'gittip', 'sun-o', 'moon-o', 'archive', 'bug', 'vk', 'weibo', 'renren', 'pagelines', 'stack-exchange', 'arrow-circle-o-right', 'arrow-circle-o-left', 'toggle-left', 'caret-square-o-left', 'dot-circle-o', 'wheelchair', 'vimeo-square', 'turkish-lira', 'try', 'plus-square-o', 'space-shuttle', 'slack', 'envelope-square', 'wordpress', 'openid', 'institution', 'bank', 'university', 'mortar-board', 'graduation-cap', 'yahoo', 'google', 'reddit', 'reddit-square', 'stumbleupon-circle', 'stumbleupon', 'delicious', 'digg', 'pied-piper-square', 'pied-piper', 'pied-piper-alt', 'drupal', 'joomla', 'language', 'fax', 'building', 'child', 'paw', 'spoon', 'cube', 'cubes', 'behance', 'behance-square', 'steam', 'steam-square', 'recycle', 'automobile', 'car', 'cab', 'taxi', 'tree', 'spotify', 'deviantart', 'soundcloud', 'database', 'file-pdf-o', 'file-word-o', 'file-excel-o', 'file-powerpoint-o', 'file-photo-o', 'file-picture-o', 'file-image-o', 'file-zip-o', 'file-archive-o', 'file-sound-o', 'file-audio-o', 'file-movie-o', 'file-video-o', 'file-code-o', 'vine', 'codepen', 'jsfiddle', 'life-bouy', 'life-saver', 'support', 'life-ring', 'circle-o-notch', 'ra', 'rebel', 'ge', 'empire', 'git-square', 'git', 'hacker-news', 'tencent-weibo', 'qq', 'wechat', 'weixin', 'send', 'paper-plane', 'send-o', 'paper-plane-o', 'history', 'circle-thin', 'header', 'paragraph', 'sliders', 'share-alt', 'share-alt-square', 'bomb');
		$num_by_hundred = array('100'=>'100', '200'=>'200', '300'=>'300', '400'=>'400', '500'=>'500', '600'=>'600', '700'=>'700', '800'=>'800', '900'=>'900', '1000'=>'1000', '1100'=>'1100', '1200'=>'1200', '1300'=>'1300', '1400'=>'1400', '1500'=>'1500', '1600'=>'1600', '1700'=>'1700', '1800'=>'1800', '1900'=>'1900', '2000'=>'2000', '2100'=>'2100', '2200'=>'2200', '2300'=>'2300', '2400'=>'2400', '2500'=>'2500', '2600'=>'2600', '2700'=>'2700', '2800'=>'2800', '2900'=>'2900', '3000'=>'3000', '3100'=>'3100', '3200'=>'3200', '3300'=>'3300', '3400'=>'3400', '3500'=>'3500', '3600'=>'3600', '3700'=>'3700', '3800'=>'3800', '3900'=>'3900', '4000'=>'4000', '4100'=>'4100', '4200'=>'4200', '4300'=>'4300', '4400'=>'4400', '4500'=>'4500', '4600'=>'4600', '4700'=>'4700', '4800'=>'4800', '4900'=>'4900', '5000'=>'5000', '5100'=>'5100', '5200'=>'5200', '5300'=>'5300', '5400'=>'5400', '5500'=>'5500', '5600'=>'5600', '5700'=>'5700', '5800'=>'5800', '5900'=>'5900', '6000'=>'6000', '6100'=>'6100', '6200'=>'6200', '6300'=>'6300', '6400'=>'6400', '6500'=>'6500', '6600'=>'6600', '6700'=>'6700', '6800'=>'6800', '6900'=>'6900', '7000'=>'7000', '7100'=>'7100', '7200'=>'7200', '7300'=>'7300', '7400'=>'7400', '7500'=>'7500', '7600'=>'7600', '7700'=>'7700', '7800'=>'7800', '7900'=>'7900', '8000'=>'8000', '8100'=>'8100', '8200'=>'8200', '8300'=>'8300', '8400'=>'8400', '8500'=>'8500', '8600'=>'8600', '8700'=>'8700', '8800'=>'8800', '8900'=>'8900', '9000'=>'9000', '9100'=>'9100', '9200'=>'9200', '9300'=>'9300', '9400'=>'9400', '9500'=>'9500', '9600'=>'9600', '9700'=>'9700', '9800'=>'9800', '9900'=>'9900', '10000'=>'10000');
	$options = array();
        
        $options[] = array(
            'name' => __('Basic Settings', 'counsel'),
            'type' => 'heading');
        
        $options[] = array(
            'name' => __('Select Skin', 'counsel'),
            'desc' => __('More Skins are available only in <a href="'.COUNSEL_PRO_URL.'" title="Get Counsel Premium Theme" target="_blank">Counsel Premium Theme</a>.', 'counsel'),
            'id' => 'skin',
            'std' => 'white',
            'type' => 'select',
            'options' => array(
                'white' => __('Classic White', 'counsel'))
        );

        $options[] = array(
            'name' => __('Logo Image:', 'counsel'),
            'desc' => '',
            'std' => '',
            'id' => 'logo_img',
            'type' => 'upload');
        
        $options[] = array(
            'name' => __('Favicon Image:', 'counsel'),
            'desc' => '',
            'std' => '',
            'id' => 'favicon',
            'type' => 'upload');
        
        $options[] = array(
            'name' => __('Company Name:', 'counsel'),
            'desc' => __('This will be shown in the Theme\'s footer.', 'counsel'),
            'id' => 'footer_name',
            'std' => '',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('Hide Header:', 'counsel'),
            'desc' => __('Checking this will hide Theme\'s Header.', 'counsel'),
            'id' => 'disable_header',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Hide Site Description:', 'counsel'),
            'desc' => __('Checking this will hide site description from the header.', 'counsel'),
            'id' => 'disable_site_desc',
            'std' => '1',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Hide Footer:', 'counsel'),
            'desc' => __('Checking this will hide Theme\'s Footer.', 'counsel'),
            'id' => 'disable_footer',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Hide Menu:', 'counsel'),
            'desc' => __('Checking this will hide Primary Menu.', 'counsel'),
            'id' => 'disable_menu',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Show Copyright:', 'counsel'),
            'desc' => __('Check this setting to show the Copyright information in the Theme\'s footer', 'counsel'),
            'id' => 'show_copyright',
            'std' => '1',
            'type' => 'checkbox');
        
        /* CTA (starts) */

        $options[] = array(
            'name' => __('Featured Section', 'counsel'),
            'type' => 'heading');

        $options[] = array(
            'name' => __('Hide Featured Section:', 'counsel'),
            'desc' => __('Checking this will hide Featured Section.', 'counsel'),
            'id' => 'disable_featured_section',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Slideshow Image #1:', 'counsel'),
            'desc' => '',
            'std' => COUNSEL_GLOBAL_IMAGES_URL . 'spring.jpg',
            'id' => 'featured_slide_img_1',
            'type' => 'upload');

        $options[] = array(
            'name' => __('Slideshow Heading #1:', 'counsel'),
            'desc' => __('The heading for slide #1', 'counsel'),
            'id' => 'featured_slide_head_1',
            'std' => 'Elegant and Stylish Theme',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Text #1:', 'counsel'),
            'desc' => __('The text content for slide #1', 'counsel'),
            'id' => 'featured_slide_text_1',
            'std' => 'Beautiful and Attractive Layout with Theme Options to configure settings easily.',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Button #1:', 'counsel'),
            'desc' => __('The button text for slide #1', 'counsel'),
            'id' => 'featured_slide_button_1',
            'std' => 'Get Premium',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Button #1 (URL):', 'counsel'),
            'desc' => __('The button URL for slide #1 (include http:// or https://)', 'counsel'),
            'id' => 'featured_slide_button_url_1',
            'std' => COUNSEL_PRO_URL,
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Image #2:', 'counsel'),
            'desc' => '',
            'std' => COUNSEL_GLOBAL_IMAGES_URL . 'flowers.jpg',
            'id' => 'featured_slide_img_2',
            'type' => 'upload');

        $options[] = array(
            'name' => __('Slideshow Heading #2:', 'counsel'),
            'desc' => __('The heading for slide #2', 'counsel'),
            'id' => 'featured_slide_head_2',
            'std' => 'Counsel WordPress Theme',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Text #2:', 'counsel'),
            'desc' => __('The text content for slide #2', 'counsel'),
            'id' => 'featured_slide_text_2',
            'std' => 'Elegant and Responsive Theme for Professionals who want to craft something awesome.',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Button #2:', 'counsel'),
            'desc' => __('The button text for slide #2', 'counsel'),
            'id' => 'featured_slide_button_2',
            'std' => 'Get Premium',
            'type' => 'textarea');

        $options[] = array(
            'name' => __('Slideshow Button #2 (URL):', 'counsel'),
            'desc' => __('The button URL for slide #2 (include http:// or https://)', 'counsel'),
            'id' => 'featured_slide_button_url_2',
            'std' => COUNSEL_PRO_URL,
            'type' => 'textarea');

        $options[] = array(
            'id' => 'mud_carousel_upgrade',
            'type' => 'carousel_upgrade');

        /* CTA (ends) */
        /* Slideshow setting (starts)*/
        $options[] = array(
            'name' => __('Slideshow Settings', 'counsel'),
            'type' => 'heading');

        $options[] = array(
            'name' => __('Slideshow Speed', 'counsel'),
            'desc' => __('Speed of slideshow', 'counsel'),
            'id' => 'slide_speed',
            'std' => '5000',
            'type' => 'select',
            'options' => $num_by_hundred);

        $options[] = array(
            'name' => __('Slideshow Animation Speed', 'counsel'),
            'desc' => __('Speed of slideshow animation', 'counsel'),
            'id' => 'slide_ani_speed',
            'std' => '700',
            'type' => 'select',
            'options' => $num_by_hundred);

        $options[] = array(
            'name' => __('Hide Navigation:', 'counsel'),
            'desc' => __('Hide left and right navigation', 'counsel'),
            'id' => 'disable_slide_nav',
            'std' => '0',
            'type' => 'checkbox');

        $options[] = array(
            'name' => __('Smooth Height:', 'counsel'),
            'desc' => __('Disable Smooth Height.', 'counsel'),
            'id' => 'disable_smooth_height',
            'std' => '1',
            'type' => 'checkbox');

        $options[] = array(
            'name' => __('Animation Type', 'counsel'),
            'desc' => __('Slideshow animation type.', 'counsel'),
            'id' => 'slide_animation_type',
            'std' => 'fade',
            'type' => 'select',
            'options' => array('fade' => 'fade', 'slide' => 'slide'));

        $options[] = array(
            'name' => __('Slideshow Direction', 'counsel'),
            'desc' => __('Slideshow Direction.', 'counsel'),
            'id' => 'slide_dir',
            'std' => 'horizontal',
            'type' => 'select',
            'options' => array('horizontal' => 'horizontal', 'vertical' => 'vertical'));

        /* Slideshow setting (ends)*/

        /*Social Options (starts)*/
        $options[] = array(
            'name' => __('Social Options', 'counsel'),
            'type' => 'heading');
        
        $options[] = array(
            'name' => __('Hide Social Section:', 'counsel'),
            'desc' => __('Checking this will hide Social Section.', 'counsel'),
            'id' => 'disable_social_section',
            'std' => '0',
            'type' => 'checkbox');
        
        $options[] = array(
            'name' => __('Telephone Number:', 'counsel'),
            'desc' => __('Your Contact me text. (This appears on the top right of screen)', 'counsel'),
            'id' => 'telephone_text',
            'std' => 'Наши контакты 99999-9999',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('Facebook Profile:', 'counsel'),
            'desc' => __('Include http:// or https:// with the URL.', 'counsel'),
            'id' => 'facebook',
            'std' => 'http://www.facebook.com',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('Twitter Profile:', 'counsel'),
            'desc' => __('Include http:// or https:// with the URL.', 'counsel'),
            'id' => 'twitter',
            'std' => 'http://www.twitter.com',
            'type' => 'text');
        
        $options[] = array(
            'name' => __('RSS Feed:', 'counsel'),
            'desc' => __('Include http:// or https:// with the URL.', 'counsel'),
            'id' => 'rss',
            'std' => get_bloginfo('rss2_url'),
            'type' => 'text');

        $options[] = array(
            'id' => 'mud_social_upgrade',
            'type' => 'social_upgrade');

        /*Social Options (ends)*/

		
        /*Custom CSS (starts)*/
        $options[] = array(
            'name' => __('Custom CSS', 'counsel'),
            'type' => 'heading');

        $options[] = array(
            'id' => "mudcss_section",
            'type' => 'divstart');

        $options[] = array(
            'name' => __('Custom CSS Styles:', 'counsel'),
            'desc' => __('<strong>Important:</strong> Use this section only if you are well versed with CSS styling. Any bad input here can ruin the entire look of your theme. You can put your custom CSS styles here. It is recommended that you use this section rather than editing <i>style.css</i> directly.', 'counsel'),
            'id' => 'custom_css',
            'std' => '',
            'type' => 'textarea');

        $options[] = array(
            'id' => "mudcss_section",
            'type' => 'divend');
        
        /*Custom CSS (ends)*/
        
	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('mudthemes_optionsframework_custom_scripts', 'mudthemes_optionsframework_custom_scripts');

function mudthemes_optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

	$('#example_showhidden').click(function() {
  		$('#section-example_text_hidden').fadeToggle(400);
	});

	if ($('#example_showhidden:checked').val() !== undefined) {
		$('#section-example_text_hidden').show();
	}

});
</script>

<?php
}